<template>
        <v-container fluid style="margin-bottom: 5rem">
            <v-row dense class="d-flex child-flex">
                <template>
                    <v-data-table :headers="headers" :items="categories" sort-by="calories" class="elevation-1">
                        <template v-slot:item.name="{ item }">
                            {{ item.name | trim(24) }}
                        </template>
                        <template v-slot:top>
                            <v-toolbar flat>
                                <v-toolbar-title>All categories</v-toolbar-title>
                                <v-divider class="mx-4" inset vertical></v-divider>
                                <v-spacer></v-spacer>
                                <v-btn small color="success" outlined dark class="ma-2" @click="toggleCategoryDialog">
                                    <v-icon left dark>mdi-plus</v-icon>
                                    Create Category
                                </v-btn>
                            </v-toolbar>
                        </template>
                        <template v-slot:item.sn="{ index }">
                            {{ index + 1 }}
                        </template>
                        <template v-slot:item.created="{ item }">
                            {{ new Date(item.created_at).toLocaleString() }}
                        </template>
                        <template v-slot:item.actions="{ item }">
                            <v-icon @click="_editCategory(item)" color="primary" small
                                    class="mr-2">
                                mdi-pencil
                            </v-icon>
                            <v-icon color="red" small @click="deleteItem(item)">
                                mdi-delete
                            </v-icon>
                        </template>
                        <template v-slot:no-data>
                            Aucune catégorie créée
                        </template>
                    </v-data-table>
                </template>
            </v-row>
            <create-category-dialog :category="editCategory" @category-updated="categoryUpdated"
                                    @close="toggleCategoryDialog" :display="categoryDialog"/>
        </v-container>
</template>

<script>
import CreateCategoryDialog from "./CreateCategoryDialog.vue";
import DashboardLayout from "../../../Components/Layouts/Dashboard.vue";
import Post from "../Post.vue";

export default {
    name: "Index",
    layout: [DashboardLayout, Post],
    components: {CreateCategoryDialog},
    data() {
        return {
            categoryDialog: false,
            categories: this.$page.props.categories,
            dialogDelete: false,
            deleteIndex: -1,
            editCategory: {},
            headers: [
                {text: 'S/N', align: 'start', sortable: false, value: `sn`},
                {text: 'Nom', align: 'start', sortable: false, value: `name`},
                {text: 'Createur', sortable: false, value: `user.name`},
                {text: 'Date', sortable: false, value: `created`},
                {text: 'Actions', sortable: false, value: 'actions'},
            ],
        }
    },
    computed: {},

    watch: {
        dialogDelete(val) {
            val || this.closeDelete()
        },
    },

    methods: {
        toggleCategoryDialog() {
            this.categoryDialog = !this.categoryDialog
            if (!this.categoryDialog) {
                this.editCategory = {}
            }
        },
        _editCategory (item) {
            this.editCategory = item
            this.toggleCategoryDialog()
        },
        categoryUpdated(data) {
            this.categories.splice(this.categories.indexOf(this.editCategory), 1, data)
        },
        deleteItem(item) {
            this.deleteIndex = this.categories.indexOf(item)
            this.dialogDelete = true
        },
        deleteItemConfirm() {
            axios.post(this.$route('article.category.delete', {agency: this.categories[this.deleteIndex].id}))
                .then(res => res.data)
                .then(data => {
                    if (data.status === 'success') {
                        this.$toast.success("Élément supprimé avec succès.")
                        this.categories.splice(this.deleteIndex, 1)
                        this.closeDelete()
                    }
                })
                .catch(err => {
                    this.$toast.error(`Une erreur s'est produite lors de la suppression de la catégorie d'articles: ${err.toString()}`)
                })
        },
        closeDelete() {
            this.dialogDelete = false
            this.$nextTick(() => {
                this.deleteIndex = -1
            })
        }
    }
}
</script>

<style scoped>

</style>
